# Examples
This directory contains some useful examples related to the stm32pio project.

## Table of contents
> - [cli](#cli)
> - [embedding](#embedding)

## CLI
Illustrated step-by-step guide to establish your first project.

## Embedding
Refer to this script to see a minimal basic set-up enough to perform most of the tasks with stm32pio projects in your code (i.e. how to include a core library (`stm32pio` folder) in 3rd party tools).
